@@ -160,7 +160,7 @@ void ImageStorage::addImage(const ImageInfo &ii)
         }
     }
 
-    for (auto tag : qAsConst(ii.tags)) {
+    for (const auto &tag : std::as_const(ii.tags)) {
         QSqlQuery query;
         query.prepare("SELECT url FROM TAGS WHERE url = ? AND tag = ?");
         query.addBindValue(ii.path);
@@ -262,7 +262,6 @@ QList<QPair<QByteArray, QString>> ImageStorage::locations(Types::LocationGroup l
             return list;
         }
 
-        QStringList groups;
         while (query.next()) {
             QString country = query.value(0).toString();
             QString state = query.value(1).toString();
@@ -477,7 +476,6 @@ QList<QPair<QByteArray, QString>> ImageStorage::timeTypes(Types::TimeGroup group
             return list;
         }
 
-        QStringList groups;
         while (query.next()) {
             QString year = query.value(0).toString();
             QString month = query.value(1).toString();
